import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';
import 'package:get/get.dart';
import 'package:cached_network_image/cached_network_image.dart';
import 'package:intl/intl.dart';
import '../../widgets/custom_app_bar.dart';
import '../../widgets/dashed_line.dart';
import 'model/payment_bank_account_info_model.dart';
import 'model/payment_method_model.dart';
import 'model/preview_order_payment_model.dart';
import 'model/preview_order_payment_point_data_model.dart';
import 'transaction_detail_viewmodel.dart';

class TransactionDetailScreen extends StatefulWidget {
  const TransactionDetailScreen({super.key});

  @override
  State<TransactionDetailScreen> createState() => _TransactionDetailScreenState();
}

class _TransactionDetailScreenState extends State<TransactionDetailScreen> {
  final TransactionDetailViewModel viewModel = Get.put(TransactionDetailViewModel());
  final currencyFormatter = NumberFormat.currency(
    locale: 'vi_VN',
    symbol: 'đ',
    decimalDigits: 0,
  );

  bool usePoints = true;
  int selectedPaymentMethodIndex = -1;
  bool isPaymentMethodsExpanded = true;

  @override
  void initState() {
    super.initState();
    viewModel.refreshData();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.grey.shade50,
      appBar: CustomAppBar.back(title: "Thông tin thanh toán"),
      body: Obx(() {
        if (viewModel.isLoading.value) {
          return const Center(child: CircularProgressIndicator());
        }

        final previewData = viewModel.previewData.value;
        if (previewData == null) {
          return const Center(child: Text('Không có dữ liệu'));
        }
        final totalPrice = previewData.totalPrice ?? 0;
        final pointValue = previewData.pointData?.point ?? 0;
        final finalTotal = usePoints && previewData.pointData?.status == 1
            ? totalPrice - pointValue
            : totalPrice;

        return Column(
          children: [
            Expanded(
              child: SingleChildScrollView(
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    _buildSectionHeader('Chi tiết giao dịch'),
                    _buildProductInfoSection(previewData),
                    if (previewData.pointData != null && previewData.pointData!.status == 1)
                      _buildPointToggleSection(previewData.pointData!),
                    _buildTotalSection(totalPrice, usePoints ? pointValue : 0, finalTotal),
                    _buildSavedCardsSection(),
                    _buildPaymentMethodsSection(),
                    const SizedBox(height: 100), // Khoảng trống để không bị che bởi bottom bar
                  ],
                ),
              ),
            ),
            // Bottom bar với tổng thanh toán và nút tiếp tục
            _buildBottomBar(finalTotal),
          ],
        );
      }),
    );
  }

  Widget _buildSectionHeader(String title) {
    return Padding(
      padding: const EdgeInsets.fromLTRB(16, 16, 16, 8),
      child: Text(
        title,
        style: const TextStyle(
          fontSize: 18,
          fontWeight: FontWeight.bold,
          color: Colors.black87,
        ),
      ),
    );
  }

  Widget _buildProductInfoSection(PreviewOrderPaymentModel data) {
    final productInfo = data.productInfo ?? [];

    return Container(
      color: Colors.white,
      child: Column(
        children: productInfo.map((item) {
          return Padding(
            padding: const EdgeInsets.symmetric(horizontal: 16, vertical: 8),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Text(
                  item.name ?? '',
                  style: TextStyle(
                    fontSize: 16,
                    color: Colors.grey.shade700,
                  ),
                ),
                Text(
                  item.value ?? '',
                  style: const TextStyle(
                    fontSize: 16,
                    fontWeight: FontWeight.w500,
                  ),
                ),
              ],
            ),
          );
        }).toList(),
      ),
    );
  }

  Widget _buildPointToggleSection(PreviewOrderPaymentPointDataModel pointData) {
    return Container(
      color: Colors.white,
      margin: const EdgeInsets.only(top: 8),
      padding: const EdgeInsets.symmetric(horizontal: 16, vertical: 12),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          Row(
            children: [
              Center(
                child: Image.asset('assets/images/ic_point.png', width: 30, height: 30),
              ),
              const SizedBox(width: 12),
              Text(
                pointData.textDisplay ?? '',
                style: const TextStyle(
                  fontSize: 16,
                  fontWeight: FontWeight.w500,
                ),
              ),
            ],
          ),
          CupertinoSwitch(
            value: usePoints,
            activeColor: Colors.green,
            onChanged: (value) {
              setState(() {
                usePoints = value;
              });
            },
          ),
        ],
      ),
    );
  }

  Widget _buildTotalSection(int totalPrice, int pointsUsed, int finalTotal) {
    return Container(
      color: Colors.white,
      margin: const EdgeInsets.only(top: 8),
      padding: const EdgeInsets.symmetric(vertical: 8),
      child: Column(
        children: [
          _buildTotalRow('Tổng số tiền', totalPrice, false),
          if (pointsUsed > 0)
            _buildTotalRow('Sử dụng điểm', -pointsUsed, false),
          _buildTotalRow('Tổng tạm tính', finalTotal, true),
        ],
      ),
    );
  }

  Widget _buildTotalRow(String label, int amount, bool isHighlighted) {
    final formattedAmount = currencyFormatter.format(amount);
    final displayAmount = amount < 0 ? formattedAmount : formattedAmount;

    return Padding(
      padding: const EdgeInsets.symmetric(horizontal: 16, vertical: 8),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          Text(
            label,
            style: TextStyle(
              fontSize: 16,
              color: isHighlighted ? Colors.black87 : Colors.grey.shade700,
            ),
          ),
          Text(
            displayAmount,
            style: TextStyle(
              fontSize: 16,
              fontWeight: FontWeight.w500,
              color: isHighlighted && amount == 0 ? Colors.red : Colors.black87,
            ),
          ),
        ],
      ),
    );
  }

  Widget _buildSavedCardsSection() {
    return Obx(() {
      final bankAccounts = viewModel.paymentBankAccounts;

      return Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          _buildSectionHeader('Tài khoản/Thẻ đã lưu'),
          Container(
            color: Colors.white,
            child: bankAccounts.isEmpty
                ? _buildNoSavedCardsItem()
                : Column(
              children: List.generate(
                bankAccounts.length,
                    (index) => _buildSavedCardItem(bankAccounts[index], index),
              ),
            ),
          ),
        ],
      );
    });
  }

  Widget _buildNoSavedCardsItem() {
    return Padding(
      padding: const EdgeInsets.symmetric(horizontal: 16, vertical: 12),
      child: Row(
        children: [
          Container(
            width: 40,
            height: 40,
            decoration: BoxDecoration(
              color: Colors.grey.shade200,
              borderRadius: BorderRadius.circular(4),
            ),
            child: const Center(
              child: Icon(
                Icons.credit_card,
                color: Colors.grey,
              ),
            ),
          ),
          const SizedBox(width: 12),
          const Text(
            'Không có thẻ đã lưu',
            style: TextStyle(
              fontSize: 16,
              fontWeight: FontWeight.w500,
            ),
          ),
        ],
      ),
    );
  }

  Widget _buildSavedCardItem(PaymentBankAccountInfoModel account, int index) {
    final isSelected = selectedPaymentMethodIndex == -1000 - index;
    return InkWell(
      onTap: () {
        setState(() {
          selectedPaymentMethodIndex = -1000 - index; // tránh đụng index method
        });
      },
      child: Container(
        margin: const EdgeInsets.symmetric(horizontal: 16, vertical: 8),
        padding: const EdgeInsets.all(12),
        decoration: BoxDecoration(
          color: Colors.white,
          border: Border.all(
            color: isSelected ? Colors.red : Colors.grey.shade300,
            width: 1.5,
          ),
          borderRadius: BorderRadius.circular(8),
        ),
        child: Row(
          children: [
            if (account.bankLogo != null)
              ClipRRect(
                borderRadius: BorderRadius.circular(4),
                child: CachedNetworkImage(
                  imageUrl: account.bankLogo!,
                  width: 32,
                  height: 32,
                  placeholder: (context, url) => Container(
                    width: 32,
                    height: 32,
                    color: Colors.grey.shade200,
                  ),
                  errorWidget: (context, url, error) => Container(
                    width: 32,
                    height: 32,
                    color: Colors.grey.shade200,
                    child: const Icon(Icons.error, size: 16),
                  ),
                ),
              ),
            const SizedBox(width: 12),
            Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text(
                  account.bankName ?? '',
                  style: const TextStyle(
                    fontSize: 16,
                    fontWeight: FontWeight.w500,
                  ),
                ),
                if (account.cardNumber != null)
                  Text(
                    '**** ${account.cardNumber!.substring(account.cardNumber!.length - 4)}',
                    style: TextStyle(color: Colors.grey.shade600),
                  ),
              ],
            ),
          ],
        ),
      ),
    );
  }

  Widget _buildPaymentMethodsSection() {
    return Obx(() {
      final methods = viewModel.paymentMethods;

      return Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Padding(
            padding: const EdgeInsets.fromLTRB(8, 8, 8, 0),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                const Text(
                  'Phương thức thanh toán khác',
                  style: TextStyle(
                    fontSize: 18,
                    fontWeight: FontWeight.bold,
                    color: Colors.black87,
                  ),
                ),
                IconButton(
                  icon: Icon(
                    isPaymentMethodsExpanded ? Icons.keyboard_arrow_up : Icons.keyboard_arrow_down,
                    color: Colors.grey,
                  ),
                  onPressed: () {
                    setState(() {
                      isPaymentMethodsExpanded = !isPaymentMethodsExpanded;
                    });
                  },
                ),
              ],
            ),
          ),
          if (isPaymentMethodsExpanded)
            Container(
              color: Colors.white,
              child: Column(
                children: List.generate(
                  methods.length,
                      (index) => _buildPaymentMethodItem(methods[index], index),
                ),
              ),
            ),
        ],
      );
    });
  }

  Widget _buildPaymentMethodItem(PaymentMethodModel method, int index) {
    final isSelected = selectedPaymentMethodIndex == index;

    return InkWell(
      onTap: () {
        setState(() {
          selectedPaymentMethodIndex = index;
        });
      },
      child: Container(
        padding: const EdgeInsets.symmetric(horizontal: 4, vertical: 4),
        decoration: BoxDecoration(
          border: index < viewModel.paymentMethods.length - 1
              ? Border(bottom: BorderSide(color: Colors.grey.shade200, width: 0.5))
              : null,
        ),
        child: Row(
          children: [
            Radio<int>(
              value: index,
              groupValue: selectedPaymentMethodIndex,
              onChanged: (value) {
                setState(() {
                  selectedPaymentMethodIndex = value!;
                });
              },
              activeColor: Colors.red,
            ),
            if (method.logo != null && method.logo!.isNotEmpty)
              ClipRRect(
                borderRadius: BorderRadius.circular(4),
                child: CachedNetworkImage(
                  imageUrl: method.logo!,
                  width: 32,
                  height: 32,
                  placeholder: (context, url) => Container(
                    width: 32,
                    height: 32,
                    color: Colors.grey.shade200,
                  ),
                  errorWidget: (context, url, error) => Container(
                    width: 32,
                    height: 32,
                    color: Colors.grey.shade200,
                    child: const Icon(Icons.error, size: 16),
                  ),
                ),
              ),
            const SizedBox(width: 12),
            Text(
              method.name ?? '',
              style: const TextStyle(
                fontSize: 16,
                fontWeight: FontWeight.w500,
              ),
            ),
          ],
        ),
      ),
    );
  }

  Widget _buildBottomBar(int finalTotal) {
    return Container(
      padding: const EdgeInsets.all(16),
      decoration: BoxDecoration(
        color: Colors.white,
        boxShadow: [
          BoxShadow(
            color: Colors.black.withOpacity(0.05),
            blurRadius: 10,
            offset: const Offset(0, -5),
          ),
        ],
      ),
      child: Column(
        children: [
          if ((viewModel.previewData.value?.feeNote ?? "").isNotEmpty)
            Text(
              viewModel.previewData.value?.feeNote ?? '',
              style: TextStyle(
                fontSize: 12,
                color: Colors.orange.shade700,
              ),
            ),
          const SizedBox(height: 12),
          Container(
            height: 1,
            color: Colors.grey.shade200,
          ),
          const SizedBox(height: 12),
          Row(
            children: [
              Expanded(
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  mainAxisSize: MainAxisSize.min,
                  children: [
                    const Text(
                      'Tổng thanh toán',
                      style: TextStyle(
                        fontSize: 14,
                        color: Colors.grey,
                      ),
                    ),
                    const SizedBox(height: 4),
                    Text(
                      currencyFormatter.format(finalTotal),
                      style: const TextStyle(
                        fontSize: 22,
                        fontWeight: FontWeight.bold,
                      ),
                    ),
                  ],
                ),
              ),
              ElevatedButton(
                onPressed: selectedPaymentMethodIndex >= 0 ? () {
                  // Xử lý khi nhấn nút tiếp tục
                  final selectedMethod = viewModel.paymentMethods[selectedPaymentMethodIndex];
                  ScaffoldMessenger.of(context).showSnackBar(
                    SnackBar(content: Text('Đang xử lý thanh toán với ${selectedMethod.name}...')),
                  );
                } : null,
                style: ElevatedButton.styleFrom(
                  backgroundColor: Colors.red,
                  foregroundColor: Colors.white,
                  padding: const EdgeInsets.symmetric(horizontal: 32, vertical: 16),
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(8),
                  ),
                  disabledBackgroundColor: Colors.red.withOpacity(0.6),
                  disabledForegroundColor: Colors.white.withOpacity(0.8),
                ),
                child: const Text(
                  'Tiếp tục',
                  style: TextStyle(
                    fontSize: 16,
                    fontWeight: FontWeight.bold,
                  ),
                ),
              ),
            ],
          ),
          const SizedBox(height: 44),
        ],
      ),
    );
  }
}